@@ -147,7 +147,7 @@
          "$May" "$MinsFromUTC" "$Minute" "$Monday" "$Mplu" "$NextMode"
          "$November" "$Now" "$NumFullOmits" "$NumPartialOmits" "$NumQueued"
          "$NumTrig" "$October" "$On" "$OnceFile" "$ParseUntriggered" "$Pm"
-         "$PrefixLineNo" "$PSCal" "$RunOff" "$Saturday" "$September"
+         "$PrefixLineNo" "$PSCal" "$RunOff" "$Saturday" "$September" "$Shaded"
          "$SimpleCal" "$SortByDate" "$SortByPrio" "$SortByTime" "$SubsIndent"
          "$Sunday" "$SuppressImplicitWarnings" "$SuppressLRM" "$SysInclude" "$T" "$Tb" "$Td"
          "$TerminalBackground" "$TerminalHyperlinks" "$Thursday" "$TimeSep" "$TimetIs64bit" "$Tm" "$Today" "$TodoFilter"
@@ -167,26 +167,151 @@
 
 (defconst remind-builtin-functions
   (sort
-   (list "_" "abs" "access" "adawn" "adusk" "ampm" "ansicolor" "args" "asc"
-         "baseyr" "catch" "catcherr" "char" "choose" "codepoint" "coerce" "columns" "const" "current" "date"
-         "datepart" "datetime" "dawn" "day" "daysinmon" "defined" "dosubst"
-         "dusk" "easterdate" "escape" "eval" "evaltrig" "filedate" "filedatetime"
-         "filedir" "filename" "getenv" "hebdate" "hebday" "hebmon" "hebyear" "hex"
-         "hour" "htmlescape" "htmlstriptags" "iif" "index" "isany" "isconst" "isdst"
-         "isleap" "isomitted" "ivritmon" "language" "localtoutc" "lower" "max"
-         "mbasc" "mbindex" "mbstrlen" "mbsubstr" "min"
-         "minsfromutc" "minute" "mon" "monnum" "moondate" "moondatetime"
-         "moonphase" "moonrise" "moonrisedir" "moonset" "moonsetdir" "moontime"
-         "multitrig" "ndawn" "ndusk" "nonconst" "nonomitted" "now" "ord" "orthodoxeaster"
-         "ostype" "pad" "plural" "psmoon" "psshade" "realcurrent" "realnow"
-         "realtoday" "rows" "sgn" "shell" "shellescape" "slide" "soleq"
-         "stdout" "strlen" "substr" "sunrise" "sunset" "time" "timepart"
-         "timezone" "today" "trig" "trigback" "trigbase" "trigcompletethrough" "trigdate" "trigdatetime"
-         "trigdelta" "trigduration" "trigeventduration" "trigeventstart" "trigeventstarttz"
-         "trigfrom" "trigger" "triginfo" "trigistodo" "trigmaxoverdue" "trigpriority" "trigrep"
-         "trigscanfrom" "trigtags" "trigtime" "trigtimedelta" "trigtimerep" "trigtimetz" "trigtz"
-         "triguntil" "trigvalid" "typeof" "tzconvert" "upper" "utctolocal"
-         "value" "version" "weekno" "wkday" "wkdaynum" "year"
+   (list
+    "_"
+    "abs"
+    "access"
+    "adawn"
+    "adusk"
+    "ampm"
+    "ansicolor"
+    "args"
+    "asc"
+    "baseyr"
+    "catch"
+    "catcherr"
+    "char"
+    "choose"
+    "codepoint"
+    "coerce"
+    "columns"
+    "const"
+    "current"
+    "date"
+    "datepart"
+    "datetime"
+    "dawn"
+    "day"
+    "daysinmon"
+    "defined"
+    "dosubst"
+    "dusk"
+    "easterdate"
+    "escape"
+    "eval"
+    "evaltrig"
+    "filedate"
+    "filedatetime"
+    "filedir"
+    "filename"
+    "getenv"
+    "hebdate"
+    "hebday"
+    "hebmon"
+    "hebyear"
+    "hex"
+    "hour"
+    "htmlescape"
+    "htmlstriptags"
+    "iif"
+    "index"
+    "isany"
+    "isconst"
+    "isdst"
+    "isleap"
+    "isomitted"
+    "ivritmon"
+    "language"
+    "localtoutc"
+    "lower"
+    "max"
+    "mbasc"
+    "mbindex"
+    "mblower"
+    "mbstrlen"
+    "mbsubstr"
+    "mbupper"
+    "min"
+    "minsfromutc"
+    "minute"
+    "mon"
+    "monnum"
+    "moondate"
+    "moondatetime"
+    "moonphase"
+    "moonrise"
+    "moonrisedir"
+    "moonset"
+    "moonsetdir"
+    "moontime"
+    "multitrig"
+    "ndawn"
+    "ndusk"
+    "nonconst"
+    "nonomitted"
+    "now"
+    "ord"
+    "orthodoxeaster"
+    "ostype"
+    "pad"
+    "plural"
+    "psmoon"
+    "psshade"
+    "realcurrent"
+    "realnow"
+    "realtoday"
+    "rows"
+    "sgn"
+    "shell"
+    "shellescape"
+    "slide"
+    "soleq"
+    "stdout"
+    "strlen"
+    "substr"
+    "sunrise"
+    "sunset"
+    "time"
+    "timepart"
+    "timezone"
+    "today"
+    "trig"
+    "trigback"
+    "trigbase"
+    "trigcompletethrough"
+    "trigdate"
+    "trigdatetime"
+    "trigdelta"
+    "trigduration"
+    "trigeventduration"
+    "trigeventstart"
+    "trigeventstarttz"
+    "trigfrom"
+    "trigger"
+    "triginfo"
+    "trigistodo"
+    "trigmaxoverdue"
+    "trigpriority"
+    "trigrep"
+    "trigscanfrom"
+    "trigtags"
+    "trigtime"
+    "trigtimedelta"
+    "trigtimerep"
+    "trigtimetz"
+    "trigtz"
+    "triguntil"
+    "trigvalid"
+    "typeof"
+    "tzconvert"
+    "upper"
+    "utctolocal"
+    "value"
+    "version"
+    "weekno"
+    "wkday"
+    "wkdaynum"
+    "year"
          )
    #'(lambda (a b) (> (length a) (length b)))))
 
