@@ -608,7 +608,28 @@ sub draw_row
         for (my $col=0; $col<7; $col++) {
                 my $day = $self->{daymap}->[$row]->[$col];
                 next if ($day < 1);
-                $self->draw_day($cr, $settings, $so_far, $day, $col, $height);
+                if ($settings->{avoid_overfull_boxes}) {
+                        my $old_entry_size = $settings->{entry_size};
+                        my $old_spacing = $settings->{entry_spacing};
+                        my $drawn = 0;
+                        while ($settings->{entry_size} >= 2.0) {
+                                my $h = $self->draw_day($cr, $settings, $so_far, $day, $col, 0);
+                                if ($h <= $height) {
+                                        $self->draw_day($cr, $settings, $so_far, $day, $col, $height);
+                                        $drawn = 1;
+                                        last;
+                                }
+                                $settings->{entry_size} -= 0.125;
+                                $settings->{entry_spacing} = $old_spacing * $settings->{entry_size} / $old_entry_size;
+                        }
+                        if (!$drawn) {
+                                $self->draw_day($cr, $settings, $so_far, $day, $col, $height);
+                        }
+                        $settings->{entry_size} = $old_entry_size;
+                        $settings->{entry_spacing} = $old_spacing;
+                } else {
+                        $self->draw_day($cr, $settings, $so_far, $day, $col, $height);
+                }
         }
 
         return $so_far + $height + $settings->{border_size} * 2;
@@ -717,8 +738,8 @@ sub draw_day
                         next;
                 }
                 if ($done) {
-                        $so_far += $settings->{border_size};
-                        $entry_height += $settings->{border_size};
+                        $so_far += $settings->{entry_spacing};
+                        $entry_height += $settings->{entry_spacing};
                 }
                 $done = 1;
                 my $h2 = $entry->render($self, $cr, $settings, $so_far, $day, $col, $height);
